@@ -19,6 +19,10 @@ class ClientSession:
         except KeyError:
             return None
 
+    @auth_id.setter
+    def auth_id(self, value):
+        self[self.AUTH_ID_FIELD] = value
+
     def __setitem__(self, key, value):
         self._data[key] = value
 
